@@ -18,6 +18,7 @@
  * SOFTWARE.
  */
 package org.jcodings;
+import org.jcodings.specific.*;
 
 final class EncodingList {
     static final void load() {
@@ -25,4 +26,11 @@ final class EncodingList {
         EncodingDB.ascii = EncodingDB.encodings.get("ASCII-8BIT".getBytes());
 %{other}
     }
+
+    public static Encoding getInstance(String name) {
+        switch (name) {
+%{switch}
+            default: return Encoding.load(name);
+        }
+    }
 }
