@@ -19,7 +19,6 @@
  */
 package org.jcodings.specific;
 
-import org.jcodings.Config;
 import org.jcodings.EucEncoding;
 import org.jcodings.IntHolder;
 import org.jcodings.ascii.AsciiTables;
@@ -39,11 +38,7 @@ public final class EUCTWEncoding extends EucEncoding {
 
     @Override
     public int length(byte[]bytes, int p, int end) {
-        if (Config.VANILLA) {
-            return length(bytes[p]);
-        } else {
-            return safeLengthForUptoFour(bytes, p, end);
-        }
+        return safeLengthForUptoFour(bytes, p, end);
     }
 
     @Override
@@ -79,12 +74,8 @@ public final class EUCTWEncoding extends EucEncoding {
     // euctw_islead
     @Override
     protected boolean isLead(int c) {
-        if (Config.VANILLA) {
-            return ((c < 0xa1 && c != 0x8e) || c == 0xff);
-        } else {
-            // 0xff equivalent to casting to unsigned char
-            return ((c - 0xa1) & 0xff) > 0xfe - 0xa1;
-        }
+        // 0xff equivalent to casting to unsigned char
+        return ((c - 0xa1) & 0xff) > 0xfe - 0xa1;
     }
 
     @Override
@@ -112,7 +103,7 @@ public final class EUCTWEncoding extends EucEncoding {
         2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 1
     };
 
-    private static final int EUCTWTrans[][] = Config.VANILLA ? null : new int[][]{
+    private static final int EUCTWTrans[][] = new int[][]{
         { /* S0   0  1  2  3  4  5  6  7  8  9  a  b  c  d  e  f */
           /* 0 */ A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A,
           /* 1 */ A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A,
