@@ -19,7 +19,6 @@
  */
 package org.jcodings.specific;
 
-import org.jcodings.Config;
 import org.jcodings.IntHolder;
 import org.jcodings.MultiByteEncoding;
 import org.jcodings.ascii.AsciiTables;
@@ -33,11 +32,7 @@ public final class EmacsMuleEncoding extends MultiByteEncoding {
 
     @Override
     public int length(byte[]bytes, int p, int end) {
-        if (Config.VANILLA){
-            return length(bytes[p]);
-        } else {
-            return safeLengthForUptoFour(bytes, p, end);
-        }
+        return safeLengthForUptoFour(bytes, p, end);
     }
 
     @Override
@@ -130,7 +125,7 @@ public final class EmacsMuleEncoding extends MultiByteEncoding {
         1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1
     };
 
-    private static final int EmacsMuleTrans[][] = Config.VANILLA ? null : new int[][]{
+    private static final int EmacsMuleTrans[][] = new int[][]{
         { /* S0   0  1  2  3  4  5  6  7  8  9  a  b  c  d  e  f */
           /* 0 */ A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A,
           /* 1 */ A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A,
